@@ -1,3 +1,3 @@
 """ Package for the debug tree display suite (excluding GUI-specific implementations). """
 
-from .base import DebugDataFactory, DebugData, package
+from .base import DebugData, DebugDataFactory, package
